@@ -19,6 +19,9 @@ and so resulted in a broken link.
 .. versionadded:: 0.7.0
 
 
+Usage
+-------
+
 .. confval:: autodocsumm_member_order
 	:type: str
 	:default: ``'alphabetical'``
@@ -31,6 +34,10 @@ and so resulted in a broken link.
 The member order can also be set on a per-directive basis using the ``:member-order: [order]`` option.
 This applies not only to :rst:dir:`automodule` etc. directives,
 but also to :rst:dir:`automodulesumm` etc. directives.
+
+
+API Reference
+----------------
 """
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -118,7 +125,7 @@ def add_autosummary(self):
 	grouped_documenters = self.get_grouped_documenters()
 
 	for section, documenters in grouped_documenters.items():
-		if not self.options.get("autosummary_no_titles", False):
+		if not self.options.get("autosummary-no-titles", False):
 			content.append(f"**{section}:**")
 
 		content.blankline(ensure_single=True)
@@ -129,7 +136,7 @@ def add_autosummary(self):
 		member_order = get_first_matching(
 				lambda x: x != "groupwise",
 				[
-						self.options.get("member_order", ''),
+						self.options.get("member-order", ''),
 						self.env.config.autodocsumm_member_order,
 						self.env.config.autodoc_member_order,
 						],
